/*
 * OpenEAS Experlog Application Server
 * Web application development and dynamic template scripting engine
 * Copyright (c) 2004 ExperLog SARL - http://www.experlog.com
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version. This program is distributed in
 * the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have
 * received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package org.experlog.db;

import java.sql.Connection;
import java.util.Vector;

/**
 * ESSimpleConnection stores a physical connection (from the
 * jdbc pool, the number of allocated connections from this one,
 * and a list of clientId, which use currently this connection
 */
public class ESSimpleConnection {

    public int count;		// number of client which use the connection
    public Connection con;	// the physical connection
    public Vector list;		// list of clients

    /**
     * constructor
     */
    public ESSimpleConnection(Connection connect, String clientId) {
        con = connect;
        count = 1;
        list = new Vector();
        list.add(clientId);
    }

    /**
     * return the current connection
     * one more client works with it.
     */
    public Connection getConnection(String clientId) {
        count++;
        list.add(clientId);
        return con;
    }

    /**
     * find the client (clientId), returns true if found, else false
     */
    public boolean findClient(String clientId) {
        return list.contains(clientId);
    }

    /**
     * remove the client (clientId) and return the number of clients
     * which use the connection now.
     */
    public int removeClient(String clientId) {
        if (list.remove(clientId)) count--;
        return count;
    }

    /**
     * return the number of clients which use the connection
     */
    public int getCount() {
        return count;
    }

}