/*
 * OpenEAS Experlog Application Server
 * Web application development and dynamic template scripting engine
 * Copyright (c) 2004 ExperLog SARL - http://www.experlog.com
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version. This program is distributed in
 * the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details. You should have
 * received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package org.experlog.openeas.api;

import java.sql.SQLException;
import java.util.List;
import java.util.ListIterator;
import java.util.Vector;

import org.experlog.util.ESSimpleDataTuple;

public class VectorDataSet implements DataSet {

  public static final int DATATUPLE = 0;
  public static final int VALUE = 1;
  public static final int HASHTABLE = 2;

  Vector data_ = null;
  boolean transient_ = true;
  ListIterator enum_ = null;
  int type_ = DATATUPLE;
  int low_ = 0;
  int high_ = -1;

  public VectorDataSet(int type, Vector v) {
    data_ = v;
    type_ = type;
  }

  public VectorDataSet(Vector v) {
    this(DATATUPLE, v);
  }

  public Vector getVector() {
    if(data_ == null) data_ = new Vector();
    return data_;
  }

  public boolean next() throws SQLException {
    return dataAvailable();
  }

  public boolean dataAvailable() throws SQLException {
    return (enum_ != null && enum_.hasNext());
  }

  public DataObject getTuple() throws SQLException {
    if(! dataAvailable()) return null;
    if(type_ == DATATUPLE) {
      return (DataObject)enum_.next();
    } else if (type_ == HASHTABLE) {
      return new HashDataObject((java.util.Hashtable)enum_.next());
    } else {
      ESSimpleDataTuple dt = new ESSimpleDataTuple();
      dt.put("value", enum_.next().toString());
      return dt;
    }
  }

  public void open() throws SQLException {
    if(data_ != null) enum_ = data_.listIterator();
  }

  public void close() throws SQLException {
    enum_ = null;
  }

  public boolean isTransient() {
    return transient_;
  }
  public void setTransient(boolean trans) {
    transient_ = trans;
  }

  public void setBoundaries(int low, int high) throws SQLException {
    List lst;
    if(data_ == null) return;
    try {
      lst = data_.subList(low-1, high);
    } catch(IndexOutOfBoundsException e) {
      throw new SQLException(e.getMessage());
    }
    enum_ = lst.listIterator();
  }

}

