/**
 * 
 */
package org.experlog.openeas.api.demo;

import org.experlog.openeas.api.Action;
import org.experlog.openeas.api.DBDataSet;
import org.experlog.openeas.api.ServletRequest;
import org.experlog.openeas.api.Session;

/**
 * @author gibello
 *
 */
public class DemoAction extends Action {

  /**
   * Server-side actions can only be executed in a template
   * Other actions can also be passed in an HTTP parameter called "Action"
   * This makes server-side actions safer, but less flexible.
   * @see org.experlog.openeas.api.Action#serverSide()
   */
  public boolean serverSide() {
    return true;
  }

  /**
   * The core of the Action.
   * Here, execute a sql query on a table called "DemoAction" (to be created).
   * Example:
   *  CREATE TABLE DemoAction(name varchar(20));
   *  INSERT INTO DemoAction VALUES("Bill");
   *  INSERT INTO DemoAction VALUES("John");
   * The result is returned as a dataset whose name is specified by the "dsname" HTTP parameter (default: "DEMOACTION")
   * A "where" clause can be specified using the "cond" HTTP parameter.
   * Example:
   *  $Action org.experlog.openeas.api.demo.DemoAction
   *  $LoopOnResults DEMOACTION r
   *   $r:name$ &lt;br/&gt;
   *  $EndLoop
   * @see org.experlog.openeas.api.Action#service(org.experlog.openeas.api.Session, org.experlog.openeas.api.ServletRequest, java.lang.Object)
   */
  public boolean service(Session s, ServletRequest r, Object info)
      throws Exception {
    
    String dsname = r.getParameter("dsname");
    if(dsname == null) dsname = "DEMOACTION";
    
    String cond = r.getParameter("condition");
    
    addDataSet(dsname, new DBDataSet(s,
        "select * from DemoAction" + (cond == null ? "" : " where " + cond),
        null));
    
    return true;
  }

}
